@@ -2,7 +2,7 @@
 #ifndef _GLIBMM_MAIN_H
 #define _GLIBMM_MAIN_H
 
-/* $Id: main.h,v 1.3 2004/01/22 18:38:11 murrayc Exp $ */
+/* $Id: main.h,v 1.5 2004/02/10 14:26:04 murrayc Exp $ */
 
 /* Copyright (C) 2002 The gtkmm Development Team
  *
@@ -180,7 +180,7 @@ public:
    * @param priority The priority of the new event source.
    * @return A connection handle, which can be used to disconnect the handler.
    */
-  SigC::Connection connect(const SigC::Slot0<bool>& slot, unsigned int interval,
+  sigc::connection connect(const sigc::slot<bool>& slot, unsigned int interval,
                            int priority = PRIORITY_DEFAULT);
 private:
   GMainContext* context_;
@@ -211,7 +211,7 @@ public:
    * @param priority The priority of the new event source.
    * @return A connection handle, which can be used to disconnect the handler.
    */
-  SigC::Connection connect(const SigC::Slot0<bool>& slot, int priority = PRIORITY_DEFAULT_IDLE);
+  sigc::connection connect(const sigc::slot<bool>& slot, int priority = PRIORITY_DEFAULT_IDLE);
 
 private:
   GMainContext* context_;
@@ -246,7 +246,7 @@ public:
    * @param priority The priority of the new event source.
    * @return A connection handle, which can be used to disconnect the handler.
    */
-  SigC::Connection connect(const SigC::Slot1<bool,IOCondition>& slot, int fd,
+  sigc::connection connect(const sigc::slot<bool,IOCondition>& slot, int fd,
                            IOCondition condition, int priority = PRIORITY_DEFAULT);
 
   /** Connects an I/O channel.
@@ -259,7 +259,7 @@ public:
    * io_source->connect(SigC::slot(&io_handler));
    * io_source->attach(Glib::MainContext::get_default());
    * @endcode
-   * @param slot A slot to call when polling @a fd results in an event that matches @a condition.
+   * @param slot A slot to call when polling @a channel results in an event that matches @a condition.
    * The event will be passed as a parameter to @a slot.
    * If @a io_handler returns <tt>false</tt> the signal is disconnected.
    * @param channel The IOChannel object to watch.
@@ -267,7 +267,7 @@ public:
    * @param priority The priority of the new event source.
    * @return A connection handle, which can be used to disconnect the handler.
    */
-  SigC::Connection connect(const SigC::Slot1<bool,IOCondition>& slot, const Glib::RefPtr<IOChannel>& channel,
+  sigc::connection connect(const sigc::slot<bool,IOCondition>& slot, const Glib::RefPtr<IOChannel>& channel,
                            IOCondition condition, int priority = PRIORITY_DEFAULT);
 
 private:
@@ -378,6 +378,7 @@ public:
    */
   void dispatch();
 
+  //TODO: Use slot instead?
   /** Sets the function to use to handle polling of file descriptors. It will be used instead of the poll() system call (or GLib's replacement function, which is used where poll() isn't available).
    * This function could possibly be used to integrate the GLib event loop with an external event loop.
    * @param poll_func The function to call to poll all file descriptors.
@@ -390,11 +391,13 @@ public:
   GPollFunc get_poll_func();
 
   /** Adds a file descriptor to the set of file descriptors polled for this context. This will very seldomly be used directly. Instead a typical event source will use Glib::Source::add_poll() instead.
-   * @param fd A GPollFD structure holding information about a file descriptor to watch.
+   * @param fd A PollFD structure holding information about a file descriptor to watch.
    * @param priority The priority for this file descriptor which should be the same as the priority used for Glib::Source::attach() to ensure that the file descriptor is polled whenever the results may be needed.
    */
   void add_poll(PollFD& fd, int priority);
+  
   /** Removes file descriptor from the set of file descriptors to be polled for a particular context.
+   * @param fd A PollFD structure holding information about a file descriptor.
    */
   void remove_poll(PollFD& fd);
 
@@ -574,7 +577,7 @@ protected:
 
   virtual ~Source();
 
-  SigC::Connection connect_generic(const SigC::SlotBase& slot);
+  sigc::connection connect_generic(const sigc::slot_base& slot);
 
   /** Adds a file descriptor to the set of file descriptors polled for this source. 
    * The event source's check function will typically test the revents field in the PollFD  and return true if events need to be processed.
@@ -588,13 +591,13 @@ protected:
   void remove_poll(PollFD& poll_fd);
 
   /** Gets the "current time" to be used when checking this source. The advantage of calling this function over calling get_current_time() directly is that when checking multiple sources, GLib can cache a single value instead of having to repeatedly get the system time.
-   * @param timeval Glib::TimeVal in which to store current time
+   * @param current_time Glib::TimeVal in which to store current time
    */
   void get_current_time(Glib::TimeVal& current_time);
 
   virtual bool prepare(int& timeout) = 0;
   virtual bool check() = 0;
-  virtual bool dispatch(SigC::SlotNode* slot_data) = 0;
+  virtual bool dispatch(sigc::slot_base* slot) = 0;
 
 private:
   GSource* gobject_;
@@ -626,7 +629,7 @@ public:
   typedef Glib::TimeoutSource CppObjectType;
 
   static Glib::RefPtr<TimeoutSource> create(unsigned int interval);
-  SigC::Connection connect(const SigC::Slot0<bool>& slot);
+  sigc::connection connect(const sigc::slot<bool>& slot);
 
 protected:
   explicit TimeoutSource(unsigned int interval);
@@ -634,7 +637,7 @@ protected:
 
   virtual bool prepare(int& timeout);
   virtual bool check();
-  virtual bool dispatch(SigC::SlotNode* slot_data);
+  virtual bool dispatch(sigc::slot_base* slot);
 
 private:
   Glib::TimeVal expiration_;
@@ -648,7 +651,7 @@ public:
   typedef Glib::IdleSource CppObjectType;
 
   static Glib::RefPtr<IdleSource> create();
-  SigC::Connection connect(const SigC::Slot0<bool>& slot);
+  sigc::connection connect(const sigc::slot<bool>& slot);
 
 protected:
   IdleSource();
@@ -656,7 +659,7 @@ protected:
 
   virtual bool prepare(int& timeout);
   virtual bool check();
-  virtual bool dispatch(SigC::SlotNode* slot_data);
+  virtual bool dispatch(sigc::slot_base* slot_data);
 };
 
 
@@ -667,7 +670,7 @@ public:
 
   static Glib::RefPtr<IOSource> create(int fd, IOCondition condition);
   static Glib::RefPtr<IOSource> create(const Glib::RefPtr<IOChannel>& channel, IOCondition condition);
-  SigC::Connection connect(const SigC::Slot1<bool,IOCondition>& slot);
+  sigc::connection connect(const sigc::slot<bool,IOCondition>& slot);
 
 protected:
   IOSource(int fd, IOCondition condition);
@@ -676,7 +679,7 @@ protected:
 
   virtual bool prepare(int& timeout);
   virtual bool check();
-  virtual bool dispatch(SigC::SlotNode* slot_data);
+  virtual bool dispatch(sigc::slot_base* slot);
 
 private:
   PollFD poll_fd_;
